diff --git a/Nuget/MediaBrowser.Common.Internal.nuspec b/Nuget/MediaBrowser.Common.Internal.nuspec
index e362a34d58..8bcec24730 100644
--- a/Nuget/MediaBrowser.Common.Internal.nuspec
+++ b/Nuget/MediaBrowser.Common.Internal.nuspec
@@ -2,7 +2,7 @@
MediaBrowser.Common.Internal
- 3.0.169
+ 3.0.170
MediaBrowser.Common.Internal
Luke
ebr,Luke,scottisafool
@@ -12,7 +12,7 @@
Contains common components shared by Media Browser Theater and Media Browser Server. Not intended for plugin developer consumption.
Copyright © Media Browser 2013
-
+
diff --git a/Nuget/MediaBrowser.Common.nuspec b/Nuget/MediaBrowser.Common.nuspec
index 47d8d8e826..82f7064aa3 100644
--- a/Nuget/MediaBrowser.Common.nuspec
+++ b/Nuget/MediaBrowser.Common.nuspec
@@ -2,7 +2,7 @@
MediaBrowser.Common
- 3.0.169
+ 3.0.170
MediaBrowser.Common
Media Browser Team
ebr,Luke,scottisafool
diff --git a/Nuget/MediaBrowser.Server.Core.nuspec b/Nuget/MediaBrowser.Server.Core.nuspec
index 58f64f8126..5d08963993 100644
--- a/Nuget/MediaBrowser.Server.Core.nuspec
+++ b/Nuget/MediaBrowser.Server.Core.nuspec
@@ -2,7 +2,7 @@
MediaBrowser.Server.Core
- 3.0.169
+ 3.0.170
Media Browser.Server.Core
Media Browser Team
ebr,Luke,scottisafool
@@ -12,7 +12,7 @@
Contains core components required to build plugins for Media Browser Server.
Copyright © Media Browser 2013
-
+
diff --git a/MediaBrowser.Model/ApiClient/IApiClient.cs b/MediaBrowser.Model/ApiClient/IApiClient.cs
index b99773e4d5..0976da05ca 100644
--- a/MediaBrowser.Model/ApiClient/IApiClient.cs
+++ b/MediaBrowser.Model/ApiClient/IApiClient.cs
@@ -608,15 +608,6 @@ namespace MediaBrowser.Model.ApiClient
/// item
string GetPersonImageUrl(BaseItemPerson item, ImageOptions options);
- ///
- /// Gets the person image URL.
- ///
- /// The item.
- /// The options.
- /// System.String.
- /// item
- string GetPersonImageUrl(BaseItemDto item, ImageOptions options);
-
///
/// Gets an image url that can be used to download an image from the api
///
@@ -643,15 +634,6 @@ namespace MediaBrowser.Model.ApiClient
/// System.String.
string GetYearImageUrl(int year, ImageOptions options);
- ///
- /// Gets the genre image URL.
- ///
- /// The item.
- /// The options.
- /// System.String.
- /// item
- string GetGenreImageUrl(BaseItemDto item, ImageOptions options);
-
///
/// Gets an image url that can be used to download an image from the api
///
@@ -662,33 +644,29 @@ namespace MediaBrowser.Model.ApiClient
string GetGenreImageUrl(string name, ImageOptions options);
///
/// Gets the studio image URL.
///
- /// The item.
+ /// The name.
/// The options.
/// System.String.
- /// item
- string GetStudioImageUrl(BaseItemDto item, ImageOptions options);
+ string GetMusicGenreImageUrl(string name, ImageOptions options);
///
/// Gets an image url that can be used to download an image from the api
///
/// The name.
/// The options.
/// System.String.
- /// name
- string GetStudioImageUrl(string name, ImageOptions options);
-
+ string GetGameGenreImageUrl(string name, ImageOptions options);
+
///
- /// Gets the artist image URL.
+ /// Gets an image url that can be used to download an image from the api
///
- /// The item.
+ /// The name.
/// The options.
/// System.String.
- /// item
- /// or
- /// options
- string GetArtistImageUrl(BaseItemDto item, ImageOptions options);
+ /// name
+ string GetStudioImageUrl(string name, ImageOptions options);
///
/// Gets the artist image URL.
@@ -662,33 +644,29 @@ namespace MediaBrowser.Model.ApiClient
string GetGenreImageUrl(string name, ImageOptions options);
///
- /// Gets the studio image URL.
+ /// Gets the music genre image URL.
///
@@ -662,33 +644,29 @@ namespace MediaBrowser.Model.ApiClient
///
- /// Gets an image url that can be used to download an image from the api
+ /// Gets the game genre image URL.
///
/// The name.